[![Build Status](https://travis-ci.org/Som-Energia/distri-remesa-parser.svg?branch=master)](https://travis-ci.org/Som-Energia/distri-remesa-parser)
# distri-remesa-parser
Python module to parser payment order files with related invoices sended by the spanish "Distribuidoras" to the "Comercializadoras"
